==> tarantool-1.10.11.52.tar.gz: tarantool-1.10.11.52/src/lib/small/test/CMakeFiles/quota.test.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/unit.c" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/quota.test.dir/unit.c.o"
  )
set(CMAKE_C_COMPILER_ID "Clang")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_C
  "CORO_ASM"
  "LUAJIT_SMART_STRINGS=1"
  "NDEBUG"
  "NVALGRIND"
  "NVALGRIND=1"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "__STDC_CONSTANT_MACROS=1"
  "__STDC_FORMAT_MACROS=1"
  "__STDC_LIMIT_MACROS=1"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "src"
  "src/lib"
  "src/lib/small/include"
  "src/lib/small/third_party"
  "third_party"
  "third_party/zstd/lib"
  "third_party/zstd/lib/common"
  "third_party/luajit/src"
  "third_party/coro"
  "third_party/libyaml/include"
  "src/lib/msgpuck"
  "build/curl/dest/include"
  "third_party/libutil_freebsd"
  "src/lib/small/small/include"
  "src/lib/small/include/small"
  )
set(CMAKE_DEPENDS_CHECK_CXX
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/quota.cc" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/quota.test.dir/quota.cc.o"
  )
set(CMAKE_CXX_COMPILER_ID "Clang")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "CORO_ASM"
  "LUAJIT_SMART_STRINGS=1"
  "NDEBUG"
  "NVALGRIND"
  "NVALGRIND=1"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "__STDC_CONSTANT_MACROS=1"
  "__STDC_FORMAT_MACROS=1"
  "__STDC_LIMIT_MACROS=1"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "src"
  "src/lib"
  "src/lib/small/include"
  "src/lib/small/third_party"
  "third_party"
  "third_party/zstd/lib"
  "third_party/zstd/lib/common"
  "third_party/luajit/src"
  "third_party/coro"
  "third_party/libyaml/include"
  "src/lib/msgpuck"
  "build/curl/dest/include"
  "third_party/libutil_freebsd"
  "src/lib/small/small/include"
  "src/lib/small/include/small"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")

==> tarantool-1.10.11.63.tar.gz: tarantool-1.10.11.63/src/lib/small/test/CMakeFiles/quota.test.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/unit.c" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/quota.test.dir/unit.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_C
  "CORO_ASM"
  "LUAJIT_SMART_STRINGS=1"
  "NDEBUG"
  "NVALGRIND"
  "NVALGRIND=1"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "__STDC_CONSTANT_MACROS=1"
  "__STDC_FORMAT_MACROS=1"
  "__STDC_LIMIT_MACROS=1"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "src"
  "src/lib"
  "src/lib/small/include"
  "src/lib/small/third_party"
  "src/lib/core"
  "third_party"
  "third_party/zstd/lib"
  "third_party/zstd/lib/common"
  "third_party/luajit/src"
  "third_party/coro"
  "third_party/libyaml/include"
  "src/lib/msgpuck"
  "build/curl/dest/include"
  "third_party/decNumber"
  "third_party/libutil_freebsd"
  "src/lib/small/small/include"
  "src/lib/small/include/small"
  )
set(CMAKE_DEPENDS_CHECK_CXX
  "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/quota.cc" "/home/ubuntu/actions-runner/_work/tarantool/tarantool/src/lib/small/test/CMakeFiles/quota.test.dir/quota.cc.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "CORO_ASM"
  "LUAJIT_SMART_STRINGS=1"
  "NDEBUG"
  "NVALGRIND"
  "NVALGRIND=1"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "__STDC_CONSTANT_MACROS=1"
  "__STDC_FORMAT_MACROS=1"
  "__STDC_LIMIT_MACROS=1"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "src"
  "src/lib"
  "src/lib/small/include"
  "src/lib/small/third_party"
  "src/lib/core"
  "third_party"
  "third_party/zstd/lib"
  "third_party/zstd/lib/common"
  "third_party/luajit/src"
  "third_party/coro"
  "third_party/libyaml/include"
  "src/lib/msgpuck"
  "build/curl/dest/include"
  "third_party/decNumber"
  "third_party/libutil_freebsd"
  "src/lib/small/small/include"
  "src/lib/small/include/small"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
